#-------------------------------------------------------------------------
# Read and wrangle data about Swedish wildfires
#-------------------------------------------------------------------------

# Get total population in each municipality
# Use the Kolada API (https://github.com/Hypergene/kolada) to download municipal data
a <- rkolada()
indicators <- a$kpi()

# Get municipality names for all municipality ids
municipalities <- a$municipality()
municipalities <- municipalities[which(municipalities$municipality.type=="K"),] # drop regions
municipalities <- municipalities[, c("municipality.id", "municipality.title")] # drop the type variable

# What is the indicator for the population variable?
indicators$kpi.id[which(str_detect(indicators$kpi.description, "Antal invånare totalt den"))]

# Retreive the values for that indicator
population <- a$values("N01951")

population <- population[which(population$gender=="T"),] # both male and female population

population <- population %>% 
  left_join(municipalities, by="municipality.id") # join population and municipality names by ids

# Select variables and rename for join
population <- population %>% 
  select(municipality.title, period, value) %>% 
  rename(Kommun=municipality.title,
         year=period,
         population=value)


# Read data on total land area
Landareal_raw <- read.xlsx("1_Raw_Data/Independent_variable/11_Kommunal_landareal_total.xlsx",
                           startRow = 7)

# Add total land area
Landareal <- Landareal_raw %>% 
  group_by(Municipality.name, County.name) %>% 
  summarise(land_area_hectar = sum(Land.area.in.hectares, na.rm = TRUE)) %>% 
  rename(Kommun = Municipality.name,
         Region = County.name)

# Join the dataframes for descriptives table
pop_area <- left_join(population, Landareal, by = "Kommun")

# Save data
saveRDS(pop_area, "2_Cleaned_Data/pop_area.rds")


# Add data on forest fires
fire_raw <- import_list("1_Raw_Data/Independent_variable/Branddata_MSB_IDA_20220319.xlsx")

# Filter for relevant criteria
fire <- data.frame(fire_raw$`Bränder i skog och mark`) %>%
  filter(manad %in% c("Maj", "Juni", "Juli", "Augusti", "September")) %>%  # months of the wildfires
  mutate(burned_area = 
           arealProduktivSkogsmark_m2 +
           arealAnnanTradbevuxenMark_m2 +
           arealMarkUtanTrad_m2) %>% # Aadd three types of fires in one index
  group_by(kommunKortNamn, ar) %>%
  summarise(burned_area = sum(burned_area)) %>% # summarize by year and municipality
  arrange(desc(burned_area)) %>%
  ungroup() %>%
  rename(Kommun = kommunKortNamn, # Kommun is Swedish for municipality. We stick with this name throughout
         year = ar)

# Read municipality code (knkod) for later mapping of data
knkod <- map_kn %>% 
  dplyr::select(Kommun = knnamn, knkod) %>% 
  mutate(Kommun = str_trim(Kommun)) %>% 
  distinct() %>% 
  arrange(Kommun)

# Join with control and index variables
fire2 <- population %>%
  filter(!is.na(Kommun) & year > 1997) %>% 
  left_join(Landareal, by = c("Kommun")) %>% 
  left_join(fire, by = c("Kommun", "year")) %>%
  left_join(knkod, by = c("Kommun")) %>% 
  mutate(burned_past = ifelse(year == 2018, 1, burned_area)) %>% 
  dplyr::select(Kommun, Region, knkod, everything())

# Convert number variables into class numeric
fire2[, 3:ncol(fire2)] <- fire2[, 3:ncol(fire2)] %>% 
  mutate_if(is.character, as.numeric) %>% # turn numeric variables into numeric class
  mutate_if(is.numeric, ~replace(., is.na(.), 0)) %>%  # turn NA's into zeroes
  mutate(knkod = str_pad(knkod, 4, pad = "0"))  # add leading zero to knkod

# Save data for later descriptive analysis
saveRDS(fire2, "2_Cleaned_Data/raw_fire_data.rds")

#-------------------------------------------------------------------------
# Create wildfire indicator
#-------------------------------------------------------------------------

# Mutate to burned forest per land area
fire_indicator <- fire2 %>% 
  filter(year == 2018) %>% # limiting forest data to year 2018
  mutate(burned_share = ((burned_area / 1000000 / land_area_hectar)),  # calculate total burned area and turn into squared kilometers
         burned_std = (burned_share-min(burned_share))/(max(burned_share)-min(burned_share))) # standardize

# View histogram
hist(fire_indicator$burned_std)

# Calculate descriptive statistics
summary(fire_indicator$burned_std)
sd(fire_indicator$burned_std)

# Save DF4 for use in robustness check
saveRDS(fire_indicator, "2_Cleaned_Data/fire_indicator.rds")

# Define latest version of forest data and name it intuitively
fire_collected <- fire2 %>%
  left_join(fire_indicator[, c("Kommun", "year", "burned_std", "burned_share")], by = c("Kommun", "year")) %>% 
  arrange(Kommun)

# Save forest data
saveRDS(fire_collected, "2_Cleaned_Data/fire_data_collected.rds")

# Show which municipalities have been hit the hardest (above the cut-off at the 85th percentile)
inspect <- fire_indicator %>%
  filter(burned_std > quantile(burned_std, 0.85)) %>%
  arrange(desc(burned_std))

# Write this indicator to file
saveRDS(inspect, "2_Cleaned_Data/indicator_inspection.rds")

# Any municipalities above the threshold in other years?
test_pre <- fire2 %>% 
  mutate(burned_share = ((burned_area / 1000000 / land_area_hectar))) %>%
  filter(year<2018) %>%
  arrange(desc(burned_share))

# Save for exclusion in robustness check
test_pre <- test_pre %>% 
  filter(burned_share > quantile(fire_indicator$burned_share, 0.85)) %>% 
  mutate(mun_year = paste0(Kommun, "_", year)) # add a municipality-year variable in order to drop these observations
  
treated_2014 <- unique(test_pre$mun_year)
saveRDS(treated_2014, "2_Cleaned_Data/treated_2014.rds")
