
#-------------------------------------------------------------------------
# Read and wrangle Swedish election data
#-------------------------------------------------------------------------

# Read data
NatEa1 <- read_excel("1_Raw_Data/Dependent_variable/Antal_stemmer.xlsx", skip=2) # read national election data
fire_collected <- readRDS("2_Cleaned_Data/fire_data_collected.rds")
inspect <- readRDS("2_Cleaned_Data/indicator_inspection.rds")

# Wrangling national election data
NatEa1 <- NatEa1 %>% select(-c(3)) #drop 1994
NatEa1$`1998` <- as.numeric(NatEa1$`1998`) 

NatEa2 <- NatEa1 %>% 
  rename(Kommun = 1, Parti = 2) %>% # rename columns
  mutate(Kommun = na.locf(Kommun)) %>%  # fill blank spaces in municipality variable
  pivot_longer(3:ncol(NatEa1), names_to = "year", values_to = "vote_share") %>% # pivot to longer format
  mutate(Kommun = str_remove(Kommun, "[:digit:]{4} "),
         vote_share = ifelse(vote_share == "..", NA, vote_share),
         vote_share = as.numeric(vote_share),
         year = as.numeric(year)) %>% 
  dplyr::select(Kommun, Parti, year, everything()) %>%  # arrange columns
  filter(!Parti %in% c("ogiltiga valsedlar", "ej röstande"), # filter out irrelevant vote types
         !is.na(Parti)) %>% # filter out municipality that is now part of another municipality 
  arrange(Kommun, Parti) # sort data

# Add experiment definers to election data
NatEa3 <- NatEa2 %>% 
  filter(Kommun!="Bara") %>% 
  arrange(Kommun) %>%
  mutate(plot_experiment = ifelse(Kommun %in% inspect$Kommun, "Treated", "Control"),
         experiment = ifelse(Kommun %in% inspect$Kommun & year == 2018, 1, 0), # treatment variable for fixed effects estimate 
         treat = ifelse(Kommun %in% inspect$Kommun, 1, 0)) # treatment group variable

# Define latest version of election data and name it intuitively
election <- NatEa3

# Save election data and joined data
saveRDS(election, "2_Cleaned_Data/election_data.rds")

# Calculate total number of eligible voters for weighted regression as robustness check
tot_votes <- NatEa1 %>% 
  rename(Kommun = 1, Parti = 2) %>% # rename columns
  mutate(Kommun = na.locf(Kommun)) %>%  # fill blank spaces in municipality variable
  pivot_longer(3:ncol(NatEa1), names_to = "year", values_to = "vote_share") %>% # pivot to longer format
  mutate(Kommun = str_remove(Kommun, "[:digit:]{4} "),
         vote_share = ifelse(vote_share == "..", NA, vote_share),
         vote_share = as.numeric(vote_share),
         year = as.numeric(year)) %>% 
  dplyr::select(Kommun, Parti, year, everything()) %>%  # arrange columns
  filter(!is.na(Parti)) %>% # filter out municipality that is now part of another municipality 
  arrange(Kommun, Parti) # sort data

# Get total votes per municipality year
tot_votes <- tot_votes %>% 
  group_by(Kommun, year) %>% 
  summarise(tot_votes = sum(vote_share)) %>% 
  ungroup()

# Save
saveRDS(tot_votes, "2_Cleaned_Data/tot_votes.rds")

#-------------------------------------------------------------------------
# Polling data
#-------------------------------------------------------------------------

# Read data
Polls <- read.xlsx("1_Raw_Data/Dependent_variable/Polls.xlsx")

# Pivot data and rename party names in poll data
P1 <- pivot_longer(Polls, cols = c(4:ncol(Polls)),
                   names_to = "Parti", 
                   values_to = "poll_share") %>% 
  mutate(Parti = case_when(Parti == "SocialdemokraternaS" ~ "The Social Democratic Party",
                           Parti == "VänsterpartietV" ~ "The Left Party",
                           Parti == "MiljöpartietMP" ~ "The Green Party",
                           Parti == "ModeraternaM" ~ "The Moderate Party",
                           Parti == "LiberalernaL" ~ "The Liberal Party",
                           Parti == "CenterpartietC" ~ "The Centre Party",
                           Parti == "KristdemokraternaKD" ~ "The Christian Democratic Party",
                           Parti == "SverigedemokraternaSD" ~ "The Sweden Democrats",
                           Parti == "Övriga.partierÖvriga" ~ "Other Parties")) %>% 
  select(Parti, poll_share, everything()) %>% 
  filter(Parti %in% c("The Social Democratic Party", "The Green Party"), # filter for parties in government in 2014/2018
         !is.na(poll_share)) %>% 
  mutate(poll_share = as.numeric(str_trim(str_remove_all(poll_share, "%"))) / 100) # remove "%" part from poll share and convert to numeric

# Create date variable for plotting
year <- "2018"
month <- str_extract(P1$Publicerad, "[:alpha:]{3}")

month <- str_replace_all(month, "jan", "01")
month <- str_replace_all(month, "feb", "02")
month <- str_replace_all(month, "mar", "03")
month <- str_replace_all(month, "apr", "04")
month <- str_replace_all(month, "maj", "05")
month <- str_replace_all(month, "jun", "06")
month <- str_replace_all(month, "jul", "07")
month <- str_replace_all(month, "aug", "08")
month <- str_replace_all(month, "sep", "09")
month <- str_replace_all(month, "okt", "10")
month <- str_replace_all(month, "nov", "11")
month <- str_replace_all(month, "dec", "12")

date <- str_trim(str_extract(P1$Publicerad, ".."))
date <- ifelse(str_detect(date, "[:digit:]{2}") == FALSE, paste("0", date, sep = ""), date)

# Convert date variable into y-m-d format
P1$date <- ymd(paste(year, month, date, sep = "-"))

# Mutate label variable for plot
P2 <- P1 %>% 
  mutate(label = case_when(date == ymd("2018-05-22") ~ "Første skovbrand",
                           date == ymd("2018-07-24") ~ "Flest skovbrande",
                           date == ymd("2018-09-09") ~ "Valgdag"))

# Save data
saveRDS(P2, "2_Cleaned_Data/polling_data.rds")


#-------------------------------------------------------------------------
# Wrangle municipal election data
#-------------------------------------------------------------------------

# Read data
Mun_E <- read.xlsx("1_Raw_Data/Dependent_variable/Kommunalvalg_1994_2022.xlsx", startRow = 3) # Read municipal election data

# Wrangling municipal election data
Mun_E2 <- Mun_E %>% 
  rename(Kommun = X1, Parti = X2) %>% # rename columns
  mutate(Kommun = na.locf(Kommun)) %>%  # fill blank spaces in municipality variable
  pivot_longer(3:ncol(Mun_E), names_to = "year", values_to = "vote_share_municipal") %>% # pivot to longer format
  mutate(Kommun = str_remove(Kommun, "[:digit:]{4} "),
         vote_share_municipal = ifelse(vote_share_municipal == "..", NA, vote_share_municipal),
         vote_share_municipal = as.numeric(vote_share_municipal),
         year = as.numeric(year)) %>% 
  dplyr::select(Kommun, Parti, year, everything()) %>%  # arrange columns
  filter(!Parti %in% c("invalid ballot papers", "non voters"), # filter out irrelevant vote types
         !year == 1994, # sort out year 1994 that includes too much missing data
         !str_detect(Kommun, "Bara|\\d|Valstatistik|uppgiften")) %>% # filter out municipality that is now part of another municipality 
  arrange(Kommun, Parti) # sort data

# Sense check amount of municipalities included for each year
table(Mun_E2$Kommun, Mun_E2$year)

# Add experiment definers to election data
Mun_E3 <- Mun_E2 %>% 
  arrange(Kommun) %>% 
  mutate(plot_experiment = ifelse(Kommun %in% inspect$Kommun, "Treated", "Control"),
         experiment = ifelse(Kommun %in% inspect$Kommun & year == 2018, 1, 0), # treatment variable for fixed effects estimate 
         treat = ifelse(Kommun %in% inspect$Kommun, 1, 0)) # treatment group variable

# Save election data and joined data
saveRDS(Mun_E3, "2_Cleaned_Data/municipal_election_data.rds")

#-------------------------------------------------------------------------
# Wrangle turnout election data
#-------------------------------------------------------------------------

# Read data
NatVa1 <- read.xlsx("1_Raw_Data/Dependent_variable/Valgdeltagelse_1994_2022.xlsx", startRow = 3) #read national voting rates

# Wrangling municipal election data
NatVa2 <- NatVa1 %>% 
  select(Kommun = 1, '1998' = 3, '2002' = 4, '2006' = 5, '2010' = 6, '2014' = 7, '2018' = 8) %>% 
  filter(!is.na(Kommun)) %>% 
  pivot_longer(2:7, names_to = "year", values_to = "turnout") %>% # pivot to longer format
  mutate(Kommun = str_remove(Kommun, "[:digit:]{4} "),
         turnout = ifelse(turnout == "..", NA, turnout),
         turnout = as.numeric(turnout),
         year = as.numeric(year)) %>% 
  filter(!year == 1994, # sort out year 1994 that includes too much missing data
         !str_detect(Kommun, "Bara|\\d|Valstatistik|means that")) %>% # filter out municipality that is now part of another municipality 
  arrange(Kommun) # sort data

# Add experiment definers to election data
NatVa3 <- NatVa2 %>% 
  arrange(Kommun) %>% 
  mutate(plot_experiment = ifelse(Kommun %in% inspect$Kommun, "Treated", "Control"),
         experiment = ifelse(Kommun %in% inspect$Kommun & year == 2018, 1, 0), # treatment variable for fixed effects estimate 
         treat = ifelse(Kommun %in% inspect$Kommun, 1, 0)) # treatment group variable

# Save election data and joined data
saveRDS(NatVa3, "2_Cleaned_Data/Turnout_data.rds")
