
#-------------------------------------------------------------------------
# Job seekers
#-------------------------------------------------------------------------

# Read raw data on job seekers 16-64 years old, 1996-2021
js <- read.xlsx("1_Raw_Data/Controls/arbejdssoegende_1996-2022.xlsx", sheet = 2)

# Name and dplyr::select variabl of interst and variables to join by
js <- js %>% 
  rename(Kommun = 1, job_seekers = 6, ym = 2) %>% 
  dplyr::select(Kommun, job_seekers, ym)
js$job_seekers <- as.numeric(js$job_seekers)

# Remove empty rows, create separate variables for year and month, filter out rows of sums  
js <- js[-c(1:6),] %>% 
  mutate(year = as.numeric(str_extract(ym, "^\\d\\d\\d\\d")),
         month = as.numeric(str_extract(ym, "\\d\\d$")),
         Kommun = na.locf(Kommun)) %>% 
  filter(!str_detect(Kommun, "Total|blank")) %>% 
  dplyr::select(-ym)

# Get total population in each municipality
# Use the Kolada API (https://github.com/Hypergene/kolada) to download municipal data
a <- rkolada()
indicators <- a$kpi()

# Get municipality names for all municipality ids
municipalities <- a$municipality()
municipalities <- municipalities[which(municipalities$municipality.type=="K"),] #drop regions
municipalities <- municipalities[, c("municipality.id", "municipality.title")] #drop the type variable

# What is the indicator for the population variable?
indicators$kpi.id[which(str_detect(indicators$kpi.description, "Antal invånare totalt den"))]

# Retrieve the values for that indicator
population <- a$values("N01951")

population <- population[which(population$gender=="T"),] # both male and female population

population <- population %>% 
  left_join(municipalities, by="municipality.id") # join population and municipality names by ids

# Select variables and rename for join
population <- population %>% 
  select(municipality.title, period, value) %>% 
  rename(Kommun=municipality.title,
         year=period,
         population=value)

# Use the share of jobseekers in the month before the election as unemployment measure
unemployment <- js %>% 
  filter(month==8) %>% left_join(population, by = c("Kommun", "year")) %>% 
  mutate(unemployment = (job_seekers/population)*100) %>%
  dplyr::select(-population, -month)

#-------------------------------------------------------------------------
# Committed crimes pr. 100.000 inhabitants
#-------------------------------------------------------------------------

# Read data
crime <- read_excel("1_Raw_Data/Controls/Forbrydelser_pr_100k_kommun.xls")

# Make row containing years the column names of the dataframe
crime <- crime %>% 
  row_to_names(row_number = 3) %>% 
  rename(Kommun = 1) %>% 
  filter(!is.na(Kommun))

# Use zoo package to fill empty values and wrangle data
crime <- crime %>%
  rename(Kommun = 1) %>% 
  filter(!is.na(Kommun)) %>% 
  mutate(Kommun = ifelse(Kommun == "Totalt antal brott", NA, Kommun), # remove values in municipality column containing the name "totals"
         Kommun = zoo::na.locf(Kommun),
         Kommun = str_remove_all(Kommun, " kommun")) %>%  
  filter(!is.na(`2018`)) %>% 
  pivot_longer(cols = 2:ncol(crime), names_to = "year", values_to = "crime") %>% 
  filter(!crime == "..",
         !(Kommun == "Heby" & crime == 0)) %>% 
  mutate(year = as.numeric(year),
         crime = as.numeric(crime),
         crime = crime / 100)

#-------------------------------------------------------------------------
# Net immigration for each municipality
#-------------------------------------------------------------------------

# What is the indicator for the immigration variabel?
indicators$kpi.id[which(str_detect(indicators$kpi.description, "Antal immigrerade minus"))]

# Retreive the values for that indicator
immigration <- a$values("N01806")

immigration <- immigration[which(immigration$gender=="T"),] # both male and female population

# Join names of municipalities
immigration <- immigration %>% 
  left_join(municipalities, by="municipality.id")

# Reduce to necessary columns only and rename appropriately
immigration <- immigration %>% 
  select(municipality.title, period, value) %>% 
  rename(Kommun=municipality.title,
         year=period,
         immigration=value)

immigration <- na.omit(immigration) # omit NAs

#-------------------------------------------------------------------------
# Budget
#-------------------------------------------------------------------------

# What is the indicator for the budget variabel?
indicators$kpi.id[which(str_detect(indicators$kpi.description, "Tillgångar totalt kommunkoncern\\,"))]

# Retreive the values for that indicator
budget <- a$values("N03049")

# Join municipalities to the budget indicator
budget <- budget %>% 
  left_join(municipalities, by="municipality.id")

# Reduce to necessary columns only and rename appropriately
budget <- budget %>% 
  select(municipality.title, period, value) %>% 
  rename(Kommun=municipality.title,
         year=period,
         budget=value)

budget$budget <- budget$budget/10000 # convert to 10.000 SEK unit for ease of interpretation

budget$budget[which(budget$budget==0)] <- NA #zeros are not true zeros but missing values

#-------------------------------------------------------------------------
# Join all the controls in a collective dataframe
#-------------------------------------------------------------------------

# Join by join_all
controls <- plyr::join_all(list(unemployment, crime, immigration, budget, population),
                           by = c("Kommun", "year"), type = "left") %>% 
  mutate(year = as.numeric(year))

# Save data
saveRDS(controls, "2_Cleaned_Data/controls.rds")

