
#-------------------------------------------------------------------------
# Gather data components for analyses and robustness
#-------------------------------------------------------------------------

# Read data
fire_collected <- readRDS("2_Cleaned_Data/fire_data_collected.rds")
election <- readRDS("2_Cleaned_Data/election_data.rds")
controls <- readRDS("2_Cleaned_Data/controls.rds")

# Calculate vote share in proportion for each municipality
D2 <- election %>% 
  group_by(Kommun, treat, experiment, year, Parti) %>% # add the Parti variable here to distinguish between the to incumbent parties
  summarise(vote_sg = sum(vote_share)) %>% 
  group_by(Kommun, experiment, year) %>% 
  mutate(vote_share = vote_sg / sum(vote_sg)) %>% 
  ungroup()

# Alter dataframe with burned_std variable to prepare for left join with vote data
burned_std_df <- fire_collected %>% 
  distinct(Kommun, year, .keep_all = TRUE) %>% 
  dplyr::select(Kommun, year, burned_std) %>% 
  arrange(desc(burned_std))

burned_past_df <- fire_collected %>% 
  distinct(Kommun, year, .keep_all = TRUE) %>% 
  dplyr::select(Kommun, year, burned_past) %>% 
  arrange(desc(burned_past))

# Join the dataframes
D3 <- left_join(D2, burned_std_df, by = c("Kommun", "year")) %>% 
  left_join(burned_past_df, by = c("Kommun", "year"))

# Join with control dataframe
D4 <- D3 %>% 
  left_join(controls, by = c("Kommun", "year")) %>%
  mutate(post = ifelse(year == 2018, 1, 0), # mutate variable for year of treatment
         vote_share = vote_share * 100) %>% 
  filter(year!=2022) # Not sufficient data

# Dataframe for DiD just for Miljöpartiet
D_mp <- D4 %>% 
  filter(Parti == "Miljöpartiet") %>% 
  group_by(Kommun, year) %>% 
  distinct() %>% 
  ungroup()

# Same Dataframe just for Socialdemokraterna
D_sd <- D4 %>% 
  filter(Parti == "Socialdemokraterna") %>% 
  group_by(Kommun, year) %>% 
  distinct() %>% 
  ungroup()

# Save for robustness check
saveRDS(D_mp, "2_Cleaned_Data/D_mp.rds")
saveRDS(D_sd, "2_Cleaned_Data/D_sd.rds")

#-------------------------------------------------------------------------
# Table 1
#-------------------------------------------------------------------------

t1 <- D_mp %>% 
  select(vote_share, budget, unemployment, immigration, crime) #select variables of interest
summary(t1)

stargazer(data.frame(t1), summary = T)

#-------------------------------------------------------------------------
# DiD parliamentary elections for the Greens
#-------------------------------------------------------------------------

# Table 2, column 1
greens_DiD1 <- felm(vote_share ~ experiment + year:treat # regress vote share on treatment only controlling for linear trend deviation
              | factor(Kommun) + factor(year)  # fixed effects for municipality and year
              |0                            # no instrument
              |Kommun,                # standard errors clustered at the municipality-level
              data = D_mp)                    
summary(greens_DiD1)

# Table 2, column 2
greens_DiD2 <- felm(vote_share ~ experiment + year:treat +
                  budget + # add budget control
                  unemployment # add unemployment control
                | factor(Kommun) + factor(year) 
                |0                          
                |Kommun,                
                data = D_mp)                    
summary(greens_DiD2)

# Table 2, column 3
greens_DiD3 <- felm(vote_share ~ experiment + year:treat +
                  budget +
                  unemployment +
                  immigration # add immigration control
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = D_mp)                    
summary(greens_DiD3)

# Table 2, column 4
greens_DiD4 <- felm(vote_share ~ experiment + year:treat +
                  budget + 
                  unemployment +
                  immigration +
                  crime # add crime control
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = D_mp)                    
summary(greens_DiD4)

# Table for LaTeX
stargazer(greens_DiD1, greens_DiD2, greens_DiD3, greens_DiD4,
          dep.var.labels = "The Greens vote share",
          covariate.labels = c("Wildfires 2018", "budget", "Unemployment", "immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

# Save full model for robustness check
saveRDS(greens_DiD4, "2_Cleaned_Data/greens_DiD4.rds")

#-------------------------------------------------------------------------
# DiD parliamentary elections for SSDP
#-------------------------------------------------------------------------

# Table 3, column 1
ssdp_DiD1 <- felm(vote_share ~ experiment + year:treat 
              | factor(Kommun) + factor(year)  
              |0                            
              |Kommun,                
              data = D_sd)                    
summary(ssdp_DiD1)

# Fixed effects with controls
ssdp_DiD2 <- felm(vote_share ~ experiment + year:treat +
                  budget +
                  unemployment
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = D_sd)                   
summary(ssdp_DiD2)

# Fixed effects with controls
ssdp_DiD3 <- felm(vote_share ~ experiment + year:treat +
                  budget +
                  unemployment +
                  immigration
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = D_sd)                   
summary(ssdp_DiD3)

# Fixed effects with controls
ssdp_DiD4 <- felm(vote_share ~ experiment + year:treat +
                  budget + 
                  unemployment +
                  immigration +
                  crime
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = D_sd)                    
summary(ssdp_DiD4)

# Table for LaTeX
stargazer(ssdp_DiD1, ssdp_DiD2, ssdp_DiD3, ssdp_DiD4,
          dep.var.labels = "SSDP vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

# Save full model for robustness check
saveRDS(ssdp_DiD4, "2_Cleaned_Data/ssdp_DiD4.rds")

#-------------------------------------------------------------------------------------------
# Load and arrange municipal elections data
#-------------------------------------------------------------------------------------------

# Read data
election_municipal <- readRDS("2_Cleaned_Data/municipal_election_data.rds")

# Calculate vote share in proportion for each municipality
D2_municipal <- election_municipal %>% 
  group_by(Kommun, experiment, year, Parti) %>%
  summarise(vote_sg = sum(vote_share_municipal)) %>% 
  group_by(Kommun, experiment, year) %>% 
  mutate(vote_share_municipal = vote_sg / sum(vote_sg)) %>% 
  ungroup()

# Join the dataframes
D3_municipal <- left_join(D2_municipal, burned_std_df, by = c("Kommun", "year")) %>% 
  left_join(burned_past_df, by = c("Kommun", "year"))

# Join with control dataframe
D4_municipal <- D3_municipal %>% 
  left_join(controls, by = c("Kommun", "year")) %>% 
  mutate(post = ifelse(year == 2018, 1, 0), # mutate variable for year of treatment
         vote_share_municipal = vote_share_municipal * 100)

#add treatment group variable
D4_municipal <- D4_municipal %>% 
  group_by(Kommun) %>% 
  mutate(treat = ifelse(sum(experiment) > 0, 1, 0)) %>% 
  ungroup() %>% 
  filter(year!=2022)

# Dataframe for DiD with fixed effects just for Miljöpartiet
D_mp_municipal <- D4_municipal %>% 
  filter(Parti == "Miljöpartiet") %>% 
  group_by(Kommun, year) %>% 
  distinct() %>% 
  ungroup()

# Dataframe for DiD with fixed effects just for Miljöpartiet
D_sd_municipal <- D4_municipal %>% 
  filter(Parti == "Socialdemokraterna") %>% 
  group_by(Kommun, year) %>% 
  distinct() %>% 
  ungroup()

#-------------------------------------------------------------------------
# DiD municipal elections for the Greens
#-------------------------------------------------------------------------

# Fixed effects without controls
greens_muni1 <- felm(vote_share_municipal ~ experiment  + year:treat 
                      | factor(Kommun) + factor(year)  
                      |0                           
                      |Kommun,                
                      data = D_mp_municipal)                    
summary(greens_muni1)

# Fixed effects with controls
greens_muni2 <- felm(vote_share_municipal ~ experiment + year:treat +
                          budget +
                          unemployment
                        | factor(Kommun) + factor(year) 
                        |0                           
                        |Kommun,                
                        data = D_mp_municipal)                    
summary(greens_muni2)

# Fixed effects with controls
greens_muni3 <- felm(vote_share_municipal ~ experiment +  year:treat +
                          budget +
                          unemployment +
                          immigration
                        | factor(Kommun) + factor(year) 
                        |0                           
                        |Kommun,                
                        data = D_mp_municipal)                    
summary(greens_muni3)

# Fixed effects with controls
greens_muni4 <- felm(vote_share_municipal ~ experiment +  year:treat +
                          budget + 
                          unemployment +
                          immigration +
                          crime
                        | factor(Kommun) + factor(year) 
                        |0                            
                        |Kommun,                
                        data = D_mp_municipal)                    
summary(greens_muni4)

# Table for LaTeX
stargazer(greens_muni1, greens_muni2, greens_muni3, greens_muni4,
          dep.var.labels = "The Greens vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

#-------------------------------------------------------------------------
# DiD municipal elections for SSDP
#-------------------------------------------------------------------------

# Fixed effects without controls
ssdp_muni1 <- felm(vote_share_municipal ~ experiment 
                         | factor(Kommun) + factor(year)  
                         |0                            
                         |Kommun,                
                         data = D_sd_municipal)                    
summary(ssdp_muni1)

# Fixed effects with controls
ssdp_muni2 <- felm(vote_share_municipal ~ experiment +
                             budget +
                             unemployment
                           | factor(Kommun) + factor(year) 
                           |0                            
                           |Kommun,                
                           data = D_sd_municipal)                    
summary(ssdp_muni2)

# Fixed effects with controls
ssdp_muni3 <- felm(vote_share_municipal ~ experiment +
                             budget +
                             unemployment +
                             immigration
                           | factor(Kommun) + factor(year) 
                           |0                            
                           |Kommun,                
                           data = D_sd_municipal)                    
summary(ssdp_muni3)

# Fixed effects with controls
ssdp_muni4 <- felm(vote_share_municipal ~ experiment +
                             budget + 
                             unemployment +
                             immigration +
                             crime
                           | factor(Kommun) + factor(year) 
                           |0                            
                           |Kommun,                
                           data = D_sd_municipal)                  
summary(ssdp_muni4)

# Table for LaTeX
stargazer(ssdp_muni1, ssdp_muni2, ssdp_muni3, ssdp_muni4,
          dep.var.labels = "SSDP vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")